@@ -1,7 +1,7 @@
 /*
  *  The Dropline Update Applet
  *
- *  Copyright 2003 Todd Kulesza <todd@dropline.net>
+ *  Copyright 2003-2004 Todd Kulesza <todd@dropline.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -64,6 +64,7 @@ struct _DroplineData {
 	gboolean check_deps;
 	
 	guint timeout_id;
+	const gchar *icon_path;
 };
 
 struct _HTTPMem
@@ -284,7 +285,7 @@ update_parse (DroplineData *data, const gchar *mesg)
 				lines [i][colon - lines[i] - 2] = '\0';
 				update_log (lines[i]);
 				update_log ("\n");
-				if (!package_disliked (lines [i]) ||
+				if (!package_disliked (lines [i]) &&
 					!package_blacklisted (lines [i]))
 				{
 					j++;
@@ -384,44 +385,58 @@ net_send_request (gpointer gdata)
 	return NULL;
 }
 
+static void
+load_image (GtkImage *image, const gchar *path, gint size)
+{
+	GdkPixbuf *pixbuf;
+	
+	pixbuf = gdk_pixbuf_new_from_file_at_size (path, size, size, NULL);
+	gtk_image_set_from_pixbuf (image, pixbuf);
+	
+	g_object_unref (G_OBJECT (pixbuf));
+	
+	return;
+}
+
 static void
 update_alert (DroplineData *data, gint status)
 {
 	const gchar *tip;
-	GdkPixbuf *pixbuf;
+	gint size;
+	
+	size = panel_applet_get_size (PANEL_APPLET (data->applet));
 	
 	switch (status)
 	{
 	case STATUS_IDLE:
 	{
-		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-idle.png", NULL);
+		data->icon_path = GNOME_ICONDIR"/dropline/applet-idle.svg";
 		tip = _("No Dropline GNOME updates are available");
 		break;
 	}
 	case STATUS_CHECKING:
 	{
-		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-checking.png", NULL);
+		data->icon_path = GNOME_ICONDIR"/dropline/applet-checking.svg";
 		tip = _("Looking for new Dropline GNOME software...");
 		break;
 	}
 	case STATUS_AVAILABLE:
 	{
-		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-available.png", NULL);
+		data->icon_path = GNOME_ICONDIR"/dropline/applet-available.svg";
 		tip = _("New Dropline GNOME software is available");
 		break;
 	}
 	default:
 	{
-		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-error.png", NULL);
+		data->icon_path = GNOME_ICONDIR"/dropline/applet-error.svg";
 		tip = _("Error while looking for updates");
 		break;
 	}
 	}
 	
 	gdk_threads_enter ();
-	gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), pixbuf);
+	load_image (GTK_IMAGE (data->image), data->icon_path, size);
 	gtk_tooltips_set_tip (data->tooltips, data->applet, tip, NULL);
-	g_object_unref (G_OBJECT (pixbuf));
 	gdk_threads_leave ();
 	
 	return;
@@ -468,7 +483,7 @@ check_for_updates_cb (gpointer gdata)
 	return TRUE;
 }
 
-void
+static void
 prefs_response (GtkWidget *dialog, gint response, DroplineData *data)
 {
 	if (response == GTK_RESPONSE_ACCEPT)
@@ -479,6 +494,36 @@ prefs_response (GtkWidget *dialog, gint response, DroplineData *data)
 	return;
 }
 
+static void
+run_installer (DroplineData *data)
+{
+	gchar *command, *check_os, *check_deps;
+	
+	update_alert (data, STATUS_IDLE);
+	
+	load_gconf_data (data);
+	
+	if (!data->check_os)
+		check_os = g_strdup ("--force");
+	else
+		check_os = g_strdup ("");
+	
+	if (!data->check_deps)
+		check_deps = g_strdup ("--nodeps");
+	else
+		check_deps = g_strdup ("");
+	
+	command = g_strdup_printf ("dropline-installer %s %s", check_os, check_deps);
+	
+	gnome_execute_terminal_shell (NULL, command);
+	
+	g_free (check_os);
+	g_free (check_deps);
+	g_free (command);
+	
+	return;
+}
+
 static void
 applet_destroy_cb (GtkWidget *widget, DroplineData *data)
 {	
@@ -522,33 +567,36 @@ applet_change_orient_cb (GtkWidget *w, PanelAppletOrient o, DroplineData *data)
 	
 	return;
 }
+
+static void
+applet_change_size_cb (GtkWidget *w, int size, DroplineData *data)
+{
+	load_image (GTK_IMAGE (data->image), data->icon_path, size);
 	
+	return;
+}
+
+static gboolean
+button_press_cb (GtkWidget *w, GdkEventButton *event, DroplineData *data)
+{
+	gboolean handled;
+	
+	/* determine whether to handle the event or not */
+	if ((event->type == GDK_BUTTON_PRESS) && (event->button == 1))
+	{
+		run_installer (data);
+		handled = TRUE;
+	}
+	else
+		handled = FALSE;
+		
+	return handled;
+}
+
 static void
 dropline_update_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *verbname)
 {
-	gchar *command, *check_os, *check_deps;
-	
-	update_alert (data, STATUS_IDLE);
-	
-	load_gconf_data (data);
-	
-	if (!data->check_os)
-		check_os = g_strdup ("--force");
-	else
-		check_os = g_strdup ("");
-	
-	if (!data->check_deps)
-		check_deps = g_strdup ("--nodeps");
-	else
-		check_deps = g_strdup ("");
-	
-	command = g_strdup_printf ("dropline-installer %s %s", check_os, check_deps);
-	
-	gnome_execute_terminal_shell (NULL, command);
-	
-	g_free (check_os);
-	g_free (check_deps);
-	g_free (command);
+	run_installer (data);
 		
 	return;
 }
@@ -717,12 +765,12 @@ dropline_about_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *verb
 	}
         
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-			"dropline.png", TRUE, NULL);
+			"dropline.svg", TRUE, NULL);
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 
 	about = gnome_about_new (_("Dropline Update Alert"), VERSION, 
-			_("Copyright 2003 Todd Kulesza"),
+			_("Copyright 2003-2004 Todd Kulesza"),
 			_("Receive alerts when new Dropline GNOME software is available."),
 			authors, documenters,
 			strcmp (translator_credits, "translator_credits") != 0 ? 
@@ -734,7 +782,7 @@ dropline_about_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *verb
 	gtk_window_set_wmclass (GTK_WINDOW(about), "dropline update alert", 
 			"Dropline Update Alert");
 	gnome_window_icon_set_from_file (GTK_WINDOW (about), 
-			GNOME_ICONDIR"/dropline.png");
+			GNOME_ICONDIR"/dropline.svg");
 	g_signal_connect (G_OBJECT (about), "destroy",
 		G_CALLBACK (gtk_widget_destroyed), &about);
 	
@@ -784,7 +832,9 @@ dropline_applet_create (PanelApplet *applet)
 	g_signal_connect (applet, "destroy", G_CALLBACK (applet_destroy_cb), data);
 	g_signal_connect (applet, "change_orient", G_CALLBACK (applet_change_orient_cb), data);
 	g_signal_connect (applet, "change_background", G_CALLBACK (applet_change_background_cb), data);
-
+	g_signal_connect (applet, "change_size", G_CALLBACK (applet_change_size_cb), data);
+	g_signal_connect (G_OBJECT (applet), "button_press_event", G_CALLBACK (button_press_cb), data);
+	
 	panel_applet_setup_menu_from_file (applet, 
 					   NULL, // opt_datadir
 					   "Dropline_UpdateApplet.xml",
